@@ -27,13 +27,13 @@ class Vision:
     # --------------- Methods
 
     # Method 1: Finding click positions based on the cv.matchTemplate() function
-    def findClickPositions(self, haystack_img_path, needle_img_path, method=cv.TM_CCOEFF_NORMED, threshold=0.9,
+    def findClickPositions(self, haystack_img, needle_img, method=cv.TM_CCOEFF_NORMED, threshold=0.9,
                            debug_mode=None, ):
         '''
         This method performs the openCV.matchTemplate()-method, using the needle_img on the haystack_img.
         Heavily inspired and mostly inherited from: https://github.com/learncodebygaming/opencv_tutorials/blob/master/003_group_rectangles/main.py
-        :param haystack_img_path:
-        :param needle_img_path:
+        :param haystack_image:
+        :param needle_image:
         :param threshold:
         :param debug_mode:
         :return click_points:
@@ -50,8 +50,6 @@ class Vision:
         marker_size = 40
 
         # Local variables
-        haystack_img = None
-        needle_img = None
         needle_img_width = 0
         needle_img_height = 0
         rectangles = []
@@ -64,10 +62,8 @@ class Vision:
         if debug_mode not in self.debug_modes:
             debug_mode = self.debug_modes[1]
 
-        # Try to load images in memory using cv.imread()
+        # We're already passing in image data from cv.imread(), get image shape now
         try:
-            haystack_img = cv.imread(haystack_img_path)
-            needle_img = cv.imread(needle_img_path)
             needle_img_width = needle_img.shape[0]
             needle_img_height = needle_img.shape[1]
         except BaseException as exception:
@@ -148,11 +144,17 @@ class Vision:
         return window_information
 
     # Method 3: Capturing the window from Albion and returning it in an openCV-understandable format
-    def captureWindow(self, window, window_width, window_height, debug_mode=False):
+    def captureWindow(self, window_width, window_height, window_handle=None, debug_mode=False):
+
+        # Parse out window handle - if it is none, we capture the whole desktop
+        # IMPORTANT: To capture the Albion client, we need to set window_handle to None, since we only capture the
+        # initial screenshot and never update it. See: https://www.youtube.com/watch?v=7k4j-uL8WSQ&list=PL1m2M8LQlzfKtkKq2lK5xko4X-8EZzFPI&t=132s
+        if window_handle is None:
+            window_handle = win32gui.GetDesktopWindow()
 
         # Get window device context - a structure that defines a set of graphic objects and their associated attributes
         # https://docs.microsoft.com/en-us/windows/win32/gdi/device-contexts
-        window_device_context = win32gui.GetWindowDC(window)
+        window_device_context = win32gui.GetWindowDC(window_handle)
         device_context = win32ui.CreateDCFromHandle(window_device_context)
         compatible_device_context = device_context.CreateCompatibleDC()
 
@@ -171,7 +173,7 @@ class Vision:
         # Free resources
         device_context.DeleteDC()
         compatible_device_context.DeleteDC()
-        win32gui.ReleaseDC(window, window_device_context)
+        win32gui.ReleaseDC(window_handle, window_device_context)
         win32gui.DeleteObject(bitmap.GetHandle())
 
         # Drop alpha channel to avoid cv.matchTemplate() error
